function [trainedClassifier, validationAccuracy] = trainClassifier_IDHinGBMnew(trainingData)
% [trainedClassifier, validationAccuracy] = trainClassifier(trainingData)
% returns a trained classifier and its accuracy. This code recreates the
% classification model trained in Classification Learner app. Use the
% generated code to automate training the same model with new data, or to
% learn how to programmatically train models.
%
%  Input:
%      trainingData: a table containing the same predictor and response
%       columns as imported into the app.
%
%  Output:
%      trainedClassifier: a struct containing the trained classifier. The
%       struct contains various fields with information about the trained
%       classifier.
%
%      trainedClassifier.predictFcn: a function to make predictions on new
%       data.
%
%      validationAccuracy: a double containing the accuracy in percent. In
%       the app, the History list displays this overall accuracy score for
%       each model.
%
% Use the code to train the model with new data. To retrain your
% classifier, call the function from the command line with your original
% data or new data as the input argument trainingData.
%
% For example, to retrain a classifier trained with the original data set
% T, enter:
%   [trainedClassifier, validationAccuracy] = trainClassifier(T)
%
% To make predictions with the returned 'trainedClassifier' on new data T2,
% use
%   yfit = trainedClassifier.predictFcn(T2)
%
% T2 must be a table containing at least the same predictor columns as used
% during training. For details, enter:
%   trainedClassifier.HowToPredict

% Auto-generated by MATLAB on 09-Apr-2018 21:37:11


% Extract predictors and response
% This code processes the data into the right shape for training the
% model.
inputTable = trainingData;
predictorNames = {'CET1_ORI_F28', 'CET1_ORI_F36', 'CET1_ORI_F170', 'CET1_ORI_F202', 'CET1_ORI_F378', 'CET1_ORI_F381', 'CET1_ORI_F386', 'CET1_ORI_F409', 'CET1_ORI_F505', 'CET1_ORI_F521', 'CET1_ORI_F585', 'CET1_ORI_F633', 'CET1_ORI_F697', 'CET1_ORI_F714', 'CET1_ORI_F826', 'CET1_ORI_F1072', 'CET1_LLL_F36', 'CET1_LLL_F90', 'CET1_LLL_F282', 'CET1_LLL_F378', 'CET1_LLL_F473', 'CET1_LLL_F491', 'CET1_LLL_F502', 'CET1_LLL_F553', 'CET1_LLL_F697', 'CET1_LLL_F720', 'CET1_LLL_F1072', 'CET1_LLH_F298', 'CET1_LLH_F362', 'CET1_LLH_F426', 'CET1_LLH_F506', 'CET1_LLH_F570', 'CET1_LLH_F573', 'CET1_LLH_F578', 'CET1_LLH_F589', 'CET1_LLH_F594', 'CET1_LLH_F762', 'CET1_LLH_F874', 'CET1_LLH_F906', 'CET1_LLH_F1066', 'CET1_LLH_F1070', 'CET1_LLH_F1071', 'CET1_LLH_F1079', 'CET1_LLH_F1081', 'CET1_LLH_F1082', 'CET1_LHL_F106', 'CET1_LHL_F109', 'CET1_LHL_F114', 'CET1_LHL_F298', 'CET1_LHL_F301', 'CET1_LHL_F306', 'CET1_LHL_F309', 'CET1_LHL_F311', 'CET1_LHL_F330', 'CET1_LHL_F346', 'CET1_LHL_F426', 'CET1_LHL_F538', 'CET1_LHL_F570', 'CET1_LHL_F634', 'CET1_LHL_F647', 'CET1_LHL_F874', 'CET1_LHL_F877', 'CET1_LHL_F882', 'CET1_LHL_F883', 'CET1_LHL_F885', 'CET1_LHL_F887', 'CET1_LHL_F906', 'CET1_LHL_F1066', 'CET1_LHH_F74', 'CET1_LHH_F378', 'CET1_LHH_F506', 'CET1_LHH_F570', 'CET1_LHH_F573', 'CET1_LHH_F578', 'CET1_LHH_F762', 'CET1_LHH_F765', 'CET1_LHH_F770', 'CET1_LHH_F775', 'CET1_LHH_F826', 'CET1_LHH_F874', 'CET1_LHH_F1034', 'CET1_LHH_F1066', 'CET1_HLL_F52', 'CET1_HLL_F426', 'CET1_HLL_F506', 'CET1_HLL_F570', 'CET1_HLL_F826', 'CET1_HLL_F829', 'CET1_HLL_F834', 'CET1_HLL_F839', 'CET1_HLL_F874', 'CET1_HLL_F1066', 'CET1_HLL_F1082', 'CET1_HLH_F202', 'CET1_HLH_F378', 'CET1_HLH_F426', 'CET1_HLH_F506', 'CET1_HLH_F874', 'CET1_HLH_F906', 'CET1_HLH_F1066', 'CET1_HHL_F62', 'CET1_HHL_F74', 'CET1_HHL_F202', 'CET1_HHL_F266', 'CET1_HHL_F298', 'CET1_HHL_F330', 'CET1_HHL_F394', 'CET1_HHL_F426', 'CET1_HHL_F506', 'CET1_HHL_F736', 'CET1_HHL_F826', 'CET1_HHL_F841', 'CET1_HHL_F874', 'CET1_HHL_F875', 'CET1_HHL_F886', 'CET1_HHL_F906', 'CET1_HHL_F922', 'CET1_HHL_F1066', 'CET1_HHL_F1081', 'CET1_HHH_F74', 'CET1_HHH_F202', 'CET1_HHH_F266', 'CET1_HHH_F330', 'CET1_HHH_F394', 'CET1_HHH_F426', 'CET1_HHH_F506', 'CET1_HHH_F570', 'CET1_HHH_F573', 'CET1_HHH_F578', 'CET1_HHH_F736', 'CET1_HHH_F874', 'CET1_HHH_F906', 'CET1_HHH_F922', 'CET1_HHH_F1034', 'CET1_HHH_F1050', 'CET1_HHH_F1066', 'T2_ORI_F28', 'T2_ORI_F35', 'T2_ORI_F71', 'T2_ORI_F106', 'T2_ORI_F122', 'T2_ORI_F234', 'T2_ORI_F317', 'T2_ORI_F322', 'T2_ORI_F327', 'T2_ORI_F330', 'T2_ORI_F426', 'T2_ORI_F506', 'T2_ORI_F586', 'T2_ORI_F698', 'T2_ORI_F701', 'T2_ORI_F706', 'T2_ORI_F826', 'T2_ORI_F874', 'T2_ORI_F890', 'T2_ORI_F1002', 'T2_ORI_F1066', 'T2_ORI_F1082', 'T2_ORI_F1085', 'T2_ORI_F1090', 'T2_ORI_F1095', 'T2_LLL_F35', 'T2_LLL_F106', 'T2_LLL_F122', 'T2_LLL_F314', 'T2_LLL_F317', 'T2_LLL_F322', 'T2_LLL_F506', 'T2_LLL_F618', 'T2_LLL_F826', 'T2_LLL_F874', 'T2_LLL_F1066', 'T2_LLL_F1082', 'T2_LLH_F107', 'T2_LLH_F186', 'T2_LLH_F199', 'T2_LLH_F266', 'T2_LLH_F298', 'T2_LLH_F346', 'T2_LLH_F378', 'T2_LLH_F394', 'T2_LLH_F762', 'T2_LLH_F826', 'T2_LLH_F874', 'T2_LLH_F938', 'T2_LLH_F941', 'T2_LLH_F946', 'T2_LLH_F1066', 'T2_LLH_F1081', 'T2_LLH_F1082', 'T2_LHL_F74', 'T2_LHL_F107', 'T2_LHL_F298', 'T2_LHL_F314', 'T2_LHL_F330', 'T2_LHL_F346', 'T2_LHL_F362', 'T2_LHL_F378', 'T2_LHL_F426', 'T2_LHL_F490', 'T2_LHL_F503', 'T2_LHL_F506', 'T2_LHL_F538', 'T2_LHL_F554', 'T2_LHL_F629', 'T2_LHL_F697', 'T2_LHL_F698', 'T2_LHL_F701', 'T2_LHL_F702', 'T2_LHL_F703', 'T2_LHL_F706', 'T2_LHL_F707', 'T2_LHL_F709', 'T2_LHL_F711', 'T2_LHL_F730', 'T2_LHL_F826', 'T2_LHL_F874', 'T2_LHL_F878', 'T2_LHL_F906', 'T2_LHL_F1002', 'T2_LHL_F1048', 'T2_LHL_F1066', 'T2_LHL_F1070', 'T2_LHL_F1071', 'T2_LHL_F1082', 'T2_LHH_F90', 'T2_LHH_F93', 'T2_LHH_F98', 'T2_LHH_F106', 'T2_LHH_F122', 'T2_LHH_F170', 'T2_LHH_F173', 'T2_LHH_F178', 'T2_LHH_F179', 'T2_LHH_F181', 'T2_LHH_F183', 'T2_LHH_F202', 'T2_LHH_F282', 'T2_LHH_F298', 'T2_LHH_F314', 'T2_LHH_F362', 'T2_LHH_F394', 'T2_LHH_F426', 'T2_LHH_F490', 'T2_LHH_F506', 'T2_LHH_F538', 'T2_LHH_F634', 'T2_LHH_F647', 'T2_LHH_F730', 'T2_LHH_F736', 'T2_LHH_F826', 'T2_LHH_F829', 'T2_LHH_F834', 'T2_LHH_F839', 'T2_LHH_F874', 'T2_LHH_F877', 'T2_LHH_F878', 'T2_LHH_F879', 'T2_LHH_F882', 'T2_LHH_F883', 'T2_LHH_F885', 'T2_LHH_F887', 'T2_LHH_F938', 'T2_LHH_F970', 'T2_LHH_F1002', 'T2_LHH_F1050', 'T2_LHH_F1066', 'T2_LHH_F1082', 'T2_HLL_F122', 'T2_HLL_F125', 'T2_HLL_F130', 'T2_HLL_F135', 'T2_HLL_F186', 'T2_HLL_F298', 'T2_HLL_F314', 'T2_HLL_F426', 'T2_HLL_F522', 'T2_HLL_F538', 'T2_HLL_F570', 'T2_HLL_F714', 'T2_HLL_F736', 'T2_HLL_F874', 'T2_HLL_F875', 'T2_HLL_F878', 'T2_HLL_F879', 'T2_HLL_F886', 'T2_HLL_F906', 'T2_HLL_F1002', 'T2_HLL_F1034', 'T2_HLL_F1066', 'T2_HLL_F1081', 'T2_HLL_F1082', 'T2_HLL_F1095', 'T2_HLH_F7', 'T2_HLH_F506', 'T2_HLH_F736', 'T2_HLH_F762', 'T2_HLH_F826', 'T2_HLH_F829', 'T2_HLH_F834', 'T2_HLH_F839', 'T2_HLH_F906', 'T2_HLH_F1066', 'T2_HLH_F1082', 'T2_HHL_F5', 'T2_HHL_F282', 'T2_HHL_F298', 'T2_HHL_F378', 'T2_HHL_F505', 'T2_HHL_F506', 'T2_HHL_F553', 'T2_HHL_F570', 'T2_HHL_F573', 'T2_HHL_F578', 'T2_HHL_F736', 'T2_HHL_F762', 'T2_HHL_F765', 'T2_HHL_F766', 'T2_HHL_F767', 'T2_HHL_F770', 'T2_HHL_F771', 'T2_HHL_F773', 'T2_HHL_F775', 'T2_HHL_F841', 'T2_HHL_F970', 'T2_HHL_F1034', 'T2_HHL_F1066', 'T2_HHL_F1081', 'T2_HHH_F5', 'T2_HHH_F23', 'T2_HHH_F41', 'T2_HHH_F43', 'T2_HHH_F44', 'T2_HHH_F74', 'T2_HHH_F202', 'T2_HHH_F298', 'T2_HHH_F330', 'T2_HHH_F426', 'T2_HHH_F506', 'T2_HHH_F509', 'T2_HHH_F510', 'T2_HHH_F511', 'T2_HHH_F514', 'T2_HHH_F515', 'T2_HHH_F517', 'T2_HHH_F519', 'T2_HHH_F570', 'T2_HHH_F736', 'T2_HHH_F826', 'T2_HHH_F874', 'T2_HHH_F906', 'T2_HHH_F1066', 'T2_HHH_F1081', 'FLAIR_ORI_F27', 'FLAIR_ORI_F28', 'FLAIR_ORI_F30', 'FLAIR_ORI_F33', 'FLAIR_ORI_F34', 'FLAIR_ORI_F35', 'FLAIR_ORI_F37', 'FLAIR_ORI_F38', 'FLAIR_ORI_F298', 'FLAIR_ORI_F314', 'FLAIR_ORI_F317', 'FLAIR_ORI_F322', 'FLAIR_ORI_F327', 'FLAIR_ORI_F538', 'FLAIR_ORI_F634', 'FLAIR_ORI_F794', 'FLAIR_ORI_F807', 'FLAIR_ORI_F826', 'FLAIR_ORI_F874', 'FLAIR_ORI_F941', 'FLAIR_ORI_F946', 'FLAIR_ORI_F1066', 'FLAIR_ORI_F1082', 'FLAIR_LLL_F28', 'FLAIR_LLL_F35', 'FLAIR_LLL_F106', 'FLAIR_LLL_F298', 'FLAIR_LLL_F442', 'FLAIR_LLL_F874', 'FLAIR_LLL_F941', 'FLAIR_LLL_F946', 'FLAIR_LLL_F954', 'FLAIR_LLL_F1066', 'FLAIR_LLH_F62', 'FLAIR_LLH_F170', 'FLAIR_LLH_F186', 'FLAIR_LLH_F189', 'FLAIR_LLH_F194', 'FLAIR_LLH_F199', 'FLAIR_LLH_F378', 'FLAIR_LLH_F490', 'FLAIR_LLH_F506', 'FLAIR_LLH_F538', 'FLAIR_LLH_F698', 'FLAIR_LLH_F714', 'FLAIR_LLH_F730', 'FLAIR_LLH_F826', 'FLAIR_LLH_F875', 'FLAIR_LLH_F886', 'FLAIR_LLH_F922', 'FLAIR_LLH_F970', 'FLAIR_LLH_F1034', 'FLAIR_LLH_F1066', 'FLAIR_LHL_F74', 'FLAIR_LHL_F90', 'FLAIR_LHL_F103', 'FLAIR_LHL_F107', 'FLAIR_LHL_F139', 'FLAIR_LHL_F202', 'FLAIR_LHL_F266', 'FLAIR_LHL_F298', 'FLAIR_LHL_F302', 'FLAIR_LHL_F346', 'FLAIR_LHL_F349', 'FLAIR_LHL_F354', 'FLAIR_LHL_F355', 'FLAIR_LHL_F357', 'FLAIR_LHL_F359', 'FLAIR_LHL_F362', 'FLAIR_LHL_F378', 'FLAIR_LHL_F394', 'FLAIR_LHL_F426', 'FLAIR_LHL_F458', 'FLAIR_LHL_F490', 'FLAIR_LHL_F506', 'FLAIR_LHL_F510', 'FLAIR_LHL_F511', 'FLAIR_LHL_F538', 'FLAIR_LHL_F570', 'FLAIR_LHL_F573', 'FLAIR_LHL_F578', 'FLAIR_LHL_F602', 'FLAIR_LHL_F736', 'FLAIR_LHL_F762', 'FLAIR_LHL_F765', 'FLAIR_LHL_F766', 'FLAIR_LHL_F767', 'FLAIR_LHL_F770', 'FLAIR_LHL_F771', 'FLAIR_LHL_F773', 'FLAIR_LHL_F775', 'FLAIR_LHL_F826', 'FLAIR_LHL_F839', 'FLAIR_LHL_F842', 'FLAIR_LHL_F845', 'FLAIR_LHL_F850', 'FLAIR_LHL_F858', 'FLAIR_LHL_F874', 'FLAIR_LHL_F875', 'FLAIR_LHL_F878', 'FLAIR_LHL_F879', 'FLAIR_LHL_F886', 'FLAIR_LHL_F887', 'FLAIR_LHL_F970', 'FLAIR_LHL_F1034', 'FLAIR_LHL_F1050', 'FLAIR_LHL_F1066', 'FLAIR_LHH_F62', 'FLAIR_LHH_F74', 'FLAIR_LHH_F394', 'FLAIR_LHH_F426', 'FLAIR_LHH_F442', 'FLAIR_LHH_F505', 'FLAIR_LHH_F506', 'FLAIR_LHH_F510', 'FLAIR_LHH_F511', 'FLAIR_LHH_F538', 'FLAIR_LHH_F570', 'FLAIR_LHH_F730', 'FLAIR_LHH_F826', 'FLAIR_LHH_F839', 'FLAIR_LHH_F842', 'FLAIR_LHH_F845', 'FLAIR_LHH_F850', 'FLAIR_LHH_F906', 'FLAIR_LHH_F922', 'FLAIR_LHH_F970', 'FLAIR_LHH_F1066', 'FLAIR_HLL_F26', 'FLAIR_HLL_F27', 'FLAIR_HLL_F30', 'FLAIR_HLL_F32', 'FLAIR_HLL_F33', 'FLAIR_HLL_F34', 'FLAIR_HLL_F37', 'FLAIR_HLL_F38', 'FLAIR_HLL_F39', 'FLAIR_HLL_F40', 'FLAIR_HLL_F47', 'FLAIR_HLL_F74', 'FLAIR_HLL_F202', 'FLAIR_HLL_F266', 'FLAIR_HLL_F298', 'FLAIR_HLL_F314', 'FLAIR_HLL_F330', 'FLAIR_HLL_F378', 'FLAIR_HLL_F394', 'FLAIR_HLL_F397', 'FLAIR_HLL_F402', 'FLAIR_HLL_F426', 'FLAIR_HLL_F458', 'FLAIR_HLL_F506', 'FLAIR_HLL_F602', 'FLAIR_HLL_F634', 'FLAIR_HLL_F714', 'FLAIR_HLL_F730', 'FLAIR_HLL_F736', 'FLAIR_HLL_F826', 'FLAIR_HLL_F842', 'FLAIR_HLL_F858', 'FLAIR_HLL_F874', 'FLAIR_HLL_F875', 'FLAIR_HLL_F886', 'FLAIR_HLL_F906', 'FLAIR_HLL_F909', 'FLAIR_HLL_F914', 'FLAIR_HLL_F970', 'FLAIR_HLL_F1034', 'FLAIR_HLL_F1050', 'FLAIR_HLL_F1066', 'FLAIR_HLL_F1082', 'FLAIR_HLH_F90', 'FLAIR_HLH_F93', 'FLAIR_HLH_F98', 'FLAIR_HLH_F103', 'FLAIR_HLH_F202', 'FLAIR_HLH_F298', 'FLAIR_HLH_F330', 'FLAIR_HLH_F378', 'FLAIR_HLH_F394', 'FLAIR_HLH_F397', 'FLAIR_HLH_F402', 'FLAIR_HLH_F426', 'FLAIR_HLH_F490', 'FLAIR_HLH_F506', 'FLAIR_HLH_F570', 'FLAIR_HLH_F762', 'FLAIR_HLH_F775', 'FLAIR_HLH_F826', 'FLAIR_HLH_F841', 'FLAIR_HLH_F842', 'FLAIR_HLH_F874', 'FLAIR_HLH_F906', 'FLAIR_HLH_F970', 'FLAIR_HLH_F1066', 'FLAIR_HLH_F1081', 'FLAIR_HHL_F7', 'FLAIR_HHL_F426', 'FLAIR_HHL_F506', 'FLAIR_HHL_F688', 'FLAIR_HHL_F730', 'FLAIR_HHL_F826', 'FLAIR_HHL_F839', 'FLAIR_HHL_F874', 'FLAIR_HHL_F906', 'FLAIR_HHL_F1066', 'FLAIR_HHL_F1081', 'FLAIR_HHH_F27', 'FLAIR_HHH_F37', 'FLAIR_HHH_F74', 'FLAIR_HHH_F202', 'FLAIR_HHH_F266', 'FLAIR_HHH_F282', 'FLAIR_HHH_F298', 'FLAIR_HHH_F330', 'FLAIR_HHH_F394', 'FLAIR_HHH_F426', 'FLAIR_HHH_F506', 'FLAIR_HHH_F538', 'FLAIR_HHH_F570', 'FLAIR_HHH_F573', 'FLAIR_HHH_F578', 'FLAIR_HHH_F602', 'FLAIR_HHH_F730', 'FLAIR_HHH_F794', 'FLAIR_HHH_F842', 'FLAIR_HHH_F874', 'FLAIR_HHH_F877', 'FLAIR_HHH_F882', 'FLAIR_HHH_F906', 'FLAIR_HHH_F970', 'FLAIR_HHH_F1034', 'FLAIR_HHH_F1050', 'FLAIR_HHH_F1066', 'FLAIR_HHH_F1081', 'age', 'gender'};
predictors = inputTable(:, predictorNames);
response = inputTable.IDH;
isCategoricalPredictor = [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true];

% Train a classifier
% This code specifies all the classifier options and trains the classifier.
classificationSVM = fitcsvm(...
    predictors, ...
    response, ...
    'KernelFunction', 'polynomial', ...
    'PolynomialOrder', 3, ...
    'KernelScale', 'auto', ...
    'BoxConstraint', 1, ...
    'Standardize', true, ...
    'ClassNames', {'Mutant'; 'WT'});

% Create the result struct with predict function
predictorExtractionFcn = @(t) t(:, predictorNames);
svmPredictFcn = @(x) predict(classificationSVM, x);
trainedClassifier.predictFcn = @(x) svmPredictFcn(predictorExtractionFcn(x));

% Add additional fields to the result struct
trainedClassifier.RequiredVariables = {'CET1_ORI_F28', 'CET1_ORI_F36', 'CET1_ORI_F170', 'CET1_ORI_F202', 'CET1_ORI_F378', 'CET1_ORI_F381', 'CET1_ORI_F386', 'CET1_ORI_F409', 'CET1_ORI_F505', 'CET1_ORI_F521', 'CET1_ORI_F585', 'CET1_ORI_F633', 'CET1_ORI_F697', 'CET1_ORI_F714', 'CET1_ORI_F826', 'CET1_ORI_F1072', 'CET1_LLL_F36', 'CET1_LLL_F90', 'CET1_LLL_F282', 'CET1_LLL_F378', 'CET1_LLL_F473', 'CET1_LLL_F491', 'CET1_LLL_F502', 'CET1_LLL_F553', 'CET1_LLL_F697', 'CET1_LLL_F720', 'CET1_LLL_F1072', 'CET1_LLH_F298', 'CET1_LLH_F362', 'CET1_LLH_F426', 'CET1_LLH_F506', 'CET1_LLH_F570', 'CET1_LLH_F573', 'CET1_LLH_F578', 'CET1_LLH_F589', 'CET1_LLH_F594', 'CET1_LLH_F762', 'CET1_LLH_F874', 'CET1_LLH_F906', 'CET1_LLH_F1066', 'CET1_LLH_F1070', 'CET1_LLH_F1071', 'CET1_LLH_F1079', 'CET1_LLH_F1081', 'CET1_LLH_F1082', 'CET1_LHL_F106', 'CET1_LHL_F109', 'CET1_LHL_F114', 'CET1_LHL_F298', 'CET1_LHL_F301', 'CET1_LHL_F306', 'CET1_LHL_F309', 'CET1_LHL_F311', 'CET1_LHL_F330', 'CET1_LHL_F346', 'CET1_LHL_F426', 'CET1_LHL_F538', 'CET1_LHL_F570', 'CET1_LHL_F634', 'CET1_LHL_F647', 'CET1_LHL_F874', 'CET1_LHL_F877', 'CET1_LHL_F882', 'CET1_LHL_F883', 'CET1_LHL_F885', 'CET1_LHL_F887', 'CET1_LHL_F906', 'CET1_LHL_F1066', 'CET1_LHH_F74', 'CET1_LHH_F378', 'CET1_LHH_F506', 'CET1_LHH_F570', 'CET1_LHH_F573', 'CET1_LHH_F578', 'CET1_LHH_F762', 'CET1_LHH_F765', 'CET1_LHH_F770', 'CET1_LHH_F775', 'CET1_LHH_F826', 'CET1_LHH_F874', 'CET1_LHH_F1034', 'CET1_LHH_F1066', 'CET1_HLL_F52', 'CET1_HLL_F426', 'CET1_HLL_F506', 'CET1_HLL_F570', 'CET1_HLL_F826', 'CET1_HLL_F829', 'CET1_HLL_F834', 'CET1_HLL_F839', 'CET1_HLL_F874', 'CET1_HLL_F1066', 'CET1_HLL_F1082', 'CET1_HLH_F202', 'CET1_HLH_F378', 'CET1_HLH_F426', 'CET1_HLH_F506', 'CET1_HLH_F874', 'CET1_HLH_F906', 'CET1_HLH_F1066', 'CET1_HHL_F62', 'CET1_HHL_F74', 'CET1_HHL_F202', 'CET1_HHL_F266', 'CET1_HHL_F298', 'CET1_HHL_F330', 'CET1_HHL_F394', 'CET1_HHL_F426', 'CET1_HHL_F506', 'CET1_HHL_F736', 'CET1_HHL_F826', 'CET1_HHL_F841', 'CET1_HHL_F874', 'CET1_HHL_F875', 'CET1_HHL_F886', 'CET1_HHL_F906', 'CET1_HHL_F922', 'CET1_HHL_F1066', 'CET1_HHL_F1081', 'CET1_HHH_F74', 'CET1_HHH_F202', 'CET1_HHH_F266', 'CET1_HHH_F330', 'CET1_HHH_F394', 'CET1_HHH_F426', 'CET1_HHH_F506', 'CET1_HHH_F570', 'CET1_HHH_F573', 'CET1_HHH_F578', 'CET1_HHH_F736', 'CET1_HHH_F874', 'CET1_HHH_F906', 'CET1_HHH_F922', 'CET1_HHH_F1034', 'CET1_HHH_F1050', 'CET1_HHH_F1066', 'T2_ORI_F28', 'T2_ORI_F35', 'T2_ORI_F71', 'T2_ORI_F106', 'T2_ORI_F122', 'T2_ORI_F234', 'T2_ORI_F317', 'T2_ORI_F322', 'T2_ORI_F327', 'T2_ORI_F330', 'T2_ORI_F426', 'T2_ORI_F506', 'T2_ORI_F586', 'T2_ORI_F698', 'T2_ORI_F701', 'T2_ORI_F706', 'T2_ORI_F826', 'T2_ORI_F874', 'T2_ORI_F890', 'T2_ORI_F1002', 'T2_ORI_F1066', 'T2_ORI_F1082', 'T2_ORI_F1085', 'T2_ORI_F1090', 'T2_ORI_F1095', 'T2_LLL_F35', 'T2_LLL_F106', 'T2_LLL_F122', 'T2_LLL_F314', 'T2_LLL_F317', 'T2_LLL_F322', 'T2_LLL_F506', 'T2_LLL_F618', 'T2_LLL_F826', 'T2_LLL_F874', 'T2_LLL_F1066', 'T2_LLL_F1082', 'T2_LLH_F107', 'T2_LLH_F186', 'T2_LLH_F199', 'T2_LLH_F266', 'T2_LLH_F298', 'T2_LLH_F346', 'T2_LLH_F378', 'T2_LLH_F394', 'T2_LLH_F762', 'T2_LLH_F826', 'T2_LLH_F874', 'T2_LLH_F938', 'T2_LLH_F941', 'T2_LLH_F946', 'T2_LLH_F1066', 'T2_LLH_F1081', 'T2_LLH_F1082', 'T2_LHL_F74', 'T2_LHL_F107', 'T2_LHL_F298', 'T2_LHL_F314', 'T2_LHL_F330', 'T2_LHL_F346', 'T2_LHL_F362', 'T2_LHL_F378', 'T2_LHL_F426', 'T2_LHL_F490', 'T2_LHL_F503', 'T2_LHL_F506', 'T2_LHL_F538', 'T2_LHL_F554', 'T2_LHL_F629', 'T2_LHL_F697', 'T2_LHL_F698', 'T2_LHL_F701', 'T2_LHL_F702', 'T2_LHL_F703', 'T2_LHL_F706', 'T2_LHL_F707', 'T2_LHL_F709', 'T2_LHL_F711', 'T2_LHL_F730', 'T2_LHL_F826', 'T2_LHL_F874', 'T2_LHL_F878', 'T2_LHL_F906', 'T2_LHL_F1002', 'T2_LHL_F1048', 'T2_LHL_F1066', 'T2_LHL_F1070', 'T2_LHL_F1071', 'T2_LHL_F1082', 'T2_LHH_F90', 'T2_LHH_F93', 'T2_LHH_F98', 'T2_LHH_F106', 'T2_LHH_F122', 'T2_LHH_F170', 'T2_LHH_F173', 'T2_LHH_F178', 'T2_LHH_F179', 'T2_LHH_F181', 'T2_LHH_F183', 'T2_LHH_F202', 'T2_LHH_F282', 'T2_LHH_F298', 'T2_LHH_F314', 'T2_LHH_F362', 'T2_LHH_F394', 'T2_LHH_F426', 'T2_LHH_F490', 'T2_LHH_F506', 'T2_LHH_F538', 'T2_LHH_F634', 'T2_LHH_F647', 'T2_LHH_F730', 'T2_LHH_F736', 'T2_LHH_F826', 'T2_LHH_F829', 'T2_LHH_F834', 'T2_LHH_F839', 'T2_LHH_F874', 'T2_LHH_F877', 'T2_LHH_F878', 'T2_LHH_F879', 'T2_LHH_F882', 'T2_LHH_F883', 'T2_LHH_F885', 'T2_LHH_F887', 'T2_LHH_F938', 'T2_LHH_F970', 'T2_LHH_F1002', 'T2_LHH_F1050', 'T2_LHH_F1066', 'T2_LHH_F1082', 'T2_HLL_F122', 'T2_HLL_F125', 'T2_HLL_F130', 'T2_HLL_F135', 'T2_HLL_F186', 'T2_HLL_F298', 'T2_HLL_F314', 'T2_HLL_F426', 'T2_HLL_F522', 'T2_HLL_F538', 'T2_HLL_F570', 'T2_HLL_F714', 'T2_HLL_F736', 'T2_HLL_F874', 'T2_HLL_F875', 'T2_HLL_F878', 'T2_HLL_F879', 'T2_HLL_F886', 'T2_HLL_F906', 'T2_HLL_F1002', 'T2_HLL_F1034', 'T2_HLL_F1066', 'T2_HLL_F1081', 'T2_HLL_F1082', 'T2_HLL_F1095', 'T2_HLH_F7', 'T2_HLH_F506', 'T2_HLH_F736', 'T2_HLH_F762', 'T2_HLH_F826', 'T2_HLH_F829', 'T2_HLH_F834', 'T2_HLH_F839', 'T2_HLH_F906', 'T2_HLH_F1066', 'T2_HLH_F1082', 'T2_HHL_F5', 'T2_HHL_F282', 'T2_HHL_F298', 'T2_HHL_F378', 'T2_HHL_F505', 'T2_HHL_F506', 'T2_HHL_F553', 'T2_HHL_F570', 'T2_HHL_F573', 'T2_HHL_F578', 'T2_HHL_F736', 'T2_HHL_F762', 'T2_HHL_F765', 'T2_HHL_F766', 'T2_HHL_F767', 'T2_HHL_F770', 'T2_HHL_F771', 'T2_HHL_F773', 'T2_HHL_F775', 'T2_HHL_F841', 'T2_HHL_F970', 'T2_HHL_F1034', 'T2_HHL_F1066', 'T2_HHL_F1081', 'T2_HHH_F5', 'T2_HHH_F23', 'T2_HHH_F41', 'T2_HHH_F43', 'T2_HHH_F44', 'T2_HHH_F74', 'T2_HHH_F202', 'T2_HHH_F298', 'T2_HHH_F330', 'T2_HHH_F426', 'T2_HHH_F506', 'T2_HHH_F509', 'T2_HHH_F510', 'T2_HHH_F511', 'T2_HHH_F514', 'T2_HHH_F515', 'T2_HHH_F517', 'T2_HHH_F519', 'T2_HHH_F570', 'T2_HHH_F736', 'T2_HHH_F826', 'T2_HHH_F874', 'T2_HHH_F906', 'T2_HHH_F1066', 'T2_HHH_F1081', 'FLAIR_ORI_F27', 'FLAIR_ORI_F28', 'FLAIR_ORI_F30', 'FLAIR_ORI_F33', 'FLAIR_ORI_F34', 'FLAIR_ORI_F35', 'FLAIR_ORI_F37', 'FLAIR_ORI_F38', 'FLAIR_ORI_F298', 'FLAIR_ORI_F314', 'FLAIR_ORI_F317', 'FLAIR_ORI_F322', 'FLAIR_ORI_F327', 'FLAIR_ORI_F538', 'FLAIR_ORI_F634', 'FLAIR_ORI_F794', 'FLAIR_ORI_F807', 'FLAIR_ORI_F826', 'FLAIR_ORI_F874', 'FLAIR_ORI_F941', 'FLAIR_ORI_F946', 'FLAIR_ORI_F1066', 'FLAIR_ORI_F1082', 'FLAIR_LLL_F28', 'FLAIR_LLL_F35', 'FLAIR_LLL_F106', 'FLAIR_LLL_F298', 'FLAIR_LLL_F442', 'FLAIR_LLL_F874', 'FLAIR_LLL_F941', 'FLAIR_LLL_F946', 'FLAIR_LLL_F954', 'FLAIR_LLL_F1066', 'FLAIR_LLH_F62', 'FLAIR_LLH_F170', 'FLAIR_LLH_F186', 'FLAIR_LLH_F189', 'FLAIR_LLH_F194', 'FLAIR_LLH_F199', 'FLAIR_LLH_F378', 'FLAIR_LLH_F490', 'FLAIR_LLH_F506', 'FLAIR_LLH_F538', 'FLAIR_LLH_F698', 'FLAIR_LLH_F714', 'FLAIR_LLH_F730', 'FLAIR_LLH_F826', 'FLAIR_LLH_F875', 'FLAIR_LLH_F886', 'FLAIR_LLH_F922', 'FLAIR_LLH_F970', 'FLAIR_LLH_F1034', 'FLAIR_LLH_F1066', 'FLAIR_LHL_F74', 'FLAIR_LHL_F90', 'FLAIR_LHL_F103', 'FLAIR_LHL_F107', 'FLAIR_LHL_F139', 'FLAIR_LHL_F202', 'FLAIR_LHL_F266', 'FLAIR_LHL_F298', 'FLAIR_LHL_F302', 'FLAIR_LHL_F346', 'FLAIR_LHL_F349', 'FLAIR_LHL_F354', 'FLAIR_LHL_F355', 'FLAIR_LHL_F357', 'FLAIR_LHL_F359', 'FLAIR_LHL_F362', 'FLAIR_LHL_F378', 'FLAIR_LHL_F394', 'FLAIR_LHL_F426', 'FLAIR_LHL_F458', 'FLAIR_LHL_F490', 'FLAIR_LHL_F506', 'FLAIR_LHL_F510', 'FLAIR_LHL_F511', 'FLAIR_LHL_F538', 'FLAIR_LHL_F570', 'FLAIR_LHL_F573', 'FLAIR_LHL_F578', 'FLAIR_LHL_F602', 'FLAIR_LHL_F736', 'FLAIR_LHL_F762', 'FLAIR_LHL_F765', 'FLAIR_LHL_F766', 'FLAIR_LHL_F767', 'FLAIR_LHL_F770', 'FLAIR_LHL_F771', 'FLAIR_LHL_F773', 'FLAIR_LHL_F775', 'FLAIR_LHL_F826', 'FLAIR_LHL_F839', 'FLAIR_LHL_F842', 'FLAIR_LHL_F845', 'FLAIR_LHL_F850', 'FLAIR_LHL_F858', 'FLAIR_LHL_F874', 'FLAIR_LHL_F875', 'FLAIR_LHL_F878', 'FLAIR_LHL_F879', 'FLAIR_LHL_F886', 'FLAIR_LHL_F887', 'FLAIR_LHL_F970', 'FLAIR_LHL_F1034', 'FLAIR_LHL_F1050', 'FLAIR_LHL_F1066', 'FLAIR_LHH_F62', 'FLAIR_LHH_F74', 'FLAIR_LHH_F394', 'FLAIR_LHH_F426', 'FLAIR_LHH_F442', 'FLAIR_LHH_F505', 'FLAIR_LHH_F506', 'FLAIR_LHH_F510', 'FLAIR_LHH_F511', 'FLAIR_LHH_F538', 'FLAIR_LHH_F570', 'FLAIR_LHH_F730', 'FLAIR_LHH_F826', 'FLAIR_LHH_F839', 'FLAIR_LHH_F842', 'FLAIR_LHH_F845', 'FLAIR_LHH_F850', 'FLAIR_LHH_F906', 'FLAIR_LHH_F922', 'FLAIR_LHH_F970', 'FLAIR_LHH_F1066', 'FLAIR_HLL_F26', 'FLAIR_HLL_F27', 'FLAIR_HLL_F30', 'FLAIR_HLL_F32', 'FLAIR_HLL_F33', 'FLAIR_HLL_F34', 'FLAIR_HLL_F37', 'FLAIR_HLL_F38', 'FLAIR_HLL_F39', 'FLAIR_HLL_F40', 'FLAIR_HLL_F47', 'FLAIR_HLL_F74', 'FLAIR_HLL_F202', 'FLAIR_HLL_F266', 'FLAIR_HLL_F298', 'FLAIR_HLL_F314', 'FLAIR_HLL_F330', 'FLAIR_HLL_F378', 'FLAIR_HLL_F394', 'FLAIR_HLL_F397', 'FLAIR_HLL_F402', 'FLAIR_HLL_F426', 'FLAIR_HLL_F458', 'FLAIR_HLL_F506', 'FLAIR_HLL_F602', 'FLAIR_HLL_F634', 'FLAIR_HLL_F714', 'FLAIR_HLL_F730', 'FLAIR_HLL_F736', 'FLAIR_HLL_F826', 'FLAIR_HLL_F842', 'FLAIR_HLL_F858', 'FLAIR_HLL_F874', 'FLAIR_HLL_F875', 'FLAIR_HLL_F886', 'FLAIR_HLL_F906', 'FLAIR_HLL_F909', 'FLAIR_HLL_F914', 'FLAIR_HLL_F970', 'FLAIR_HLL_F1034', 'FLAIR_HLL_F1050', 'FLAIR_HLL_F1066', 'FLAIR_HLL_F1082', 'FLAIR_HLH_F90', 'FLAIR_HLH_F93', 'FLAIR_HLH_F98', 'FLAIR_HLH_F103', 'FLAIR_HLH_F202', 'FLAIR_HLH_F298', 'FLAIR_HLH_F330', 'FLAIR_HLH_F378', 'FLAIR_HLH_F394', 'FLAIR_HLH_F397', 'FLAIR_HLH_F402', 'FLAIR_HLH_F426', 'FLAIR_HLH_F490', 'FLAIR_HLH_F506', 'FLAIR_HLH_F570', 'FLAIR_HLH_F762', 'FLAIR_HLH_F775', 'FLAIR_HLH_F826', 'FLAIR_HLH_F841', 'FLAIR_HLH_F842', 'FLAIR_HLH_F874', 'FLAIR_HLH_F906', 'FLAIR_HLH_F970', 'FLAIR_HLH_F1066', 'FLAIR_HLH_F1081', 'FLAIR_HHL_F7', 'FLAIR_HHL_F426', 'FLAIR_HHL_F506', 'FLAIR_HHL_F688', 'FLAIR_HHL_F730', 'FLAIR_HHL_F826', 'FLAIR_HHL_F839', 'FLAIR_HHL_F874', 'FLAIR_HHL_F906', 'FLAIR_HHL_F1066', 'FLAIR_HHL_F1081', 'FLAIR_HHH_F27', 'FLAIR_HHH_F37', 'FLAIR_HHH_F74', 'FLAIR_HHH_F202', 'FLAIR_HHH_F266', 'FLAIR_HHH_F282', 'FLAIR_HHH_F298', 'FLAIR_HHH_F330', 'FLAIR_HHH_F394', 'FLAIR_HHH_F426', 'FLAIR_HHH_F506', 'FLAIR_HHH_F538', 'FLAIR_HHH_F570', 'FLAIR_HHH_F573', 'FLAIR_HHH_F578', 'FLAIR_HHH_F602', 'FLAIR_HHH_F730', 'FLAIR_HHH_F794', 'FLAIR_HHH_F842', 'FLAIR_HHH_F874', 'FLAIR_HHH_F877', 'FLAIR_HHH_F882', 'FLAIR_HHH_F906', 'FLAIR_HHH_F970', 'FLAIR_HHH_F1034', 'FLAIR_HHH_F1050', 'FLAIR_HHH_F1066', 'FLAIR_HHH_F1081', 'age', 'gender'};
trainedClassifier.ClassificationSVM = classificationSVM;
trainedClassifier.About = 'This struct is a trained model exported from Classification Learner R2017a.';
trainedClassifier.HowToPredict = sprintf('To make predictions on a new table, T, use: \n  yfit = c.predictFcn(T) \nreplacing ''c'' with the name of the variable that is this struct, e.g. ''trainedModel''. \n \nThe table, T, must contain the variables returned by: \n  c.RequiredVariables \nVariable formats (e.g. matrix/vector, datatype) must match the original training data. \nAdditional variables are ignored. \n \nFor more information, see <a href="matlab:helpview(fullfile(docroot, ''stats'', ''stats.map''), ''appclassification_exportmodeltoworkspace'')">How to predict using an exported model</a>.');

% Extract predictors and response
% This code processes the data into the right shape for training the
% model.
inputTable = trainingData;
predictorNames = {'CET1_ORI_F28', 'CET1_ORI_F36', 'CET1_ORI_F170', 'CET1_ORI_F202', 'CET1_ORI_F378', 'CET1_ORI_F381', 'CET1_ORI_F386', 'CET1_ORI_F409', 'CET1_ORI_F505', 'CET1_ORI_F521', 'CET1_ORI_F585', 'CET1_ORI_F633', 'CET1_ORI_F697', 'CET1_ORI_F714', 'CET1_ORI_F826', 'CET1_ORI_F1072', 'CET1_LLL_F36', 'CET1_LLL_F90', 'CET1_LLL_F282', 'CET1_LLL_F378', 'CET1_LLL_F473', 'CET1_LLL_F491', 'CET1_LLL_F502', 'CET1_LLL_F553', 'CET1_LLL_F697', 'CET1_LLL_F720', 'CET1_LLL_F1072', 'CET1_LLH_F298', 'CET1_LLH_F362', 'CET1_LLH_F426', 'CET1_LLH_F506', 'CET1_LLH_F570', 'CET1_LLH_F573', 'CET1_LLH_F578', 'CET1_LLH_F589', 'CET1_LLH_F594', 'CET1_LLH_F762', 'CET1_LLH_F874', 'CET1_LLH_F906', 'CET1_LLH_F1066', 'CET1_LLH_F1070', 'CET1_LLH_F1071', 'CET1_LLH_F1079', 'CET1_LLH_F1081', 'CET1_LLH_F1082', 'CET1_LHL_F106', 'CET1_LHL_F109', 'CET1_LHL_F114', 'CET1_LHL_F298', 'CET1_LHL_F301', 'CET1_LHL_F306', 'CET1_LHL_F309', 'CET1_LHL_F311', 'CET1_LHL_F330', 'CET1_LHL_F346', 'CET1_LHL_F426', 'CET1_LHL_F538', 'CET1_LHL_F570', 'CET1_LHL_F634', 'CET1_LHL_F647', 'CET1_LHL_F874', 'CET1_LHL_F877', 'CET1_LHL_F882', 'CET1_LHL_F883', 'CET1_LHL_F885', 'CET1_LHL_F887', 'CET1_LHL_F906', 'CET1_LHL_F1066', 'CET1_LHH_F74', 'CET1_LHH_F378', 'CET1_LHH_F506', 'CET1_LHH_F570', 'CET1_LHH_F573', 'CET1_LHH_F578', 'CET1_LHH_F762', 'CET1_LHH_F765', 'CET1_LHH_F770', 'CET1_LHH_F775', 'CET1_LHH_F826', 'CET1_LHH_F874', 'CET1_LHH_F1034', 'CET1_LHH_F1066', 'CET1_HLL_F52', 'CET1_HLL_F426', 'CET1_HLL_F506', 'CET1_HLL_F570', 'CET1_HLL_F826', 'CET1_HLL_F829', 'CET1_HLL_F834', 'CET1_HLL_F839', 'CET1_HLL_F874', 'CET1_HLL_F1066', 'CET1_HLL_F1082', 'CET1_HLH_F202', 'CET1_HLH_F378', 'CET1_HLH_F426', 'CET1_HLH_F506', 'CET1_HLH_F874', 'CET1_HLH_F906', 'CET1_HLH_F1066', 'CET1_HHL_F62', 'CET1_HHL_F74', 'CET1_HHL_F202', 'CET1_HHL_F266', 'CET1_HHL_F298', 'CET1_HHL_F330', 'CET1_HHL_F394', 'CET1_HHL_F426', 'CET1_HHL_F506', 'CET1_HHL_F736', 'CET1_HHL_F826', 'CET1_HHL_F841', 'CET1_HHL_F874', 'CET1_HHL_F875', 'CET1_HHL_F886', 'CET1_HHL_F906', 'CET1_HHL_F922', 'CET1_HHL_F1066', 'CET1_HHL_F1081', 'CET1_HHH_F74', 'CET1_HHH_F202', 'CET1_HHH_F266', 'CET1_HHH_F330', 'CET1_HHH_F394', 'CET1_HHH_F426', 'CET1_HHH_F506', 'CET1_HHH_F570', 'CET1_HHH_F573', 'CET1_HHH_F578', 'CET1_HHH_F736', 'CET1_HHH_F874', 'CET1_HHH_F906', 'CET1_HHH_F922', 'CET1_HHH_F1034', 'CET1_HHH_F1050', 'CET1_HHH_F1066', 'T2_ORI_F28', 'T2_ORI_F35', 'T2_ORI_F71', 'T2_ORI_F106', 'T2_ORI_F122', 'T2_ORI_F234', 'T2_ORI_F317', 'T2_ORI_F322', 'T2_ORI_F327', 'T2_ORI_F330', 'T2_ORI_F426', 'T2_ORI_F506', 'T2_ORI_F586', 'T2_ORI_F698', 'T2_ORI_F701', 'T2_ORI_F706', 'T2_ORI_F826', 'T2_ORI_F874', 'T2_ORI_F890', 'T2_ORI_F1002', 'T2_ORI_F1066', 'T2_ORI_F1082', 'T2_ORI_F1085', 'T2_ORI_F1090', 'T2_ORI_F1095', 'T2_LLL_F35', 'T2_LLL_F106', 'T2_LLL_F122', 'T2_LLL_F314', 'T2_LLL_F317', 'T2_LLL_F322', 'T2_LLL_F506', 'T2_LLL_F618', 'T2_LLL_F826', 'T2_LLL_F874', 'T2_LLL_F1066', 'T2_LLL_F1082', 'T2_LLH_F107', 'T2_LLH_F186', 'T2_LLH_F199', 'T2_LLH_F266', 'T2_LLH_F298', 'T2_LLH_F346', 'T2_LLH_F378', 'T2_LLH_F394', 'T2_LLH_F762', 'T2_LLH_F826', 'T2_LLH_F874', 'T2_LLH_F938', 'T2_LLH_F941', 'T2_LLH_F946', 'T2_LLH_F1066', 'T2_LLH_F1081', 'T2_LLH_F1082', 'T2_LHL_F74', 'T2_LHL_F107', 'T2_LHL_F298', 'T2_LHL_F314', 'T2_LHL_F330', 'T2_LHL_F346', 'T2_LHL_F362', 'T2_LHL_F378', 'T2_LHL_F426', 'T2_LHL_F490', 'T2_LHL_F503', 'T2_LHL_F506', 'T2_LHL_F538', 'T2_LHL_F554', 'T2_LHL_F629', 'T2_LHL_F697', 'T2_LHL_F698', 'T2_LHL_F701', 'T2_LHL_F702', 'T2_LHL_F703', 'T2_LHL_F706', 'T2_LHL_F707', 'T2_LHL_F709', 'T2_LHL_F711', 'T2_LHL_F730', 'T2_LHL_F826', 'T2_LHL_F874', 'T2_LHL_F878', 'T2_LHL_F906', 'T2_LHL_F1002', 'T2_LHL_F1048', 'T2_LHL_F1066', 'T2_LHL_F1070', 'T2_LHL_F1071', 'T2_LHL_F1082', 'T2_LHH_F90', 'T2_LHH_F93', 'T2_LHH_F98', 'T2_LHH_F106', 'T2_LHH_F122', 'T2_LHH_F170', 'T2_LHH_F173', 'T2_LHH_F178', 'T2_LHH_F179', 'T2_LHH_F181', 'T2_LHH_F183', 'T2_LHH_F202', 'T2_LHH_F282', 'T2_LHH_F298', 'T2_LHH_F314', 'T2_LHH_F362', 'T2_LHH_F394', 'T2_LHH_F426', 'T2_LHH_F490', 'T2_LHH_F506', 'T2_LHH_F538', 'T2_LHH_F634', 'T2_LHH_F647', 'T2_LHH_F730', 'T2_LHH_F736', 'T2_LHH_F826', 'T2_LHH_F829', 'T2_LHH_F834', 'T2_LHH_F839', 'T2_LHH_F874', 'T2_LHH_F877', 'T2_LHH_F878', 'T2_LHH_F879', 'T2_LHH_F882', 'T2_LHH_F883', 'T2_LHH_F885', 'T2_LHH_F887', 'T2_LHH_F938', 'T2_LHH_F970', 'T2_LHH_F1002', 'T2_LHH_F1050', 'T2_LHH_F1066', 'T2_LHH_F1082', 'T2_HLL_F122', 'T2_HLL_F125', 'T2_HLL_F130', 'T2_HLL_F135', 'T2_HLL_F186', 'T2_HLL_F298', 'T2_HLL_F314', 'T2_HLL_F426', 'T2_HLL_F522', 'T2_HLL_F538', 'T2_HLL_F570', 'T2_HLL_F714', 'T2_HLL_F736', 'T2_HLL_F874', 'T2_HLL_F875', 'T2_HLL_F878', 'T2_HLL_F879', 'T2_HLL_F886', 'T2_HLL_F906', 'T2_HLL_F1002', 'T2_HLL_F1034', 'T2_HLL_F1066', 'T2_HLL_F1081', 'T2_HLL_F1082', 'T2_HLL_F1095', 'T2_HLH_F7', 'T2_HLH_F506', 'T2_HLH_F736', 'T2_HLH_F762', 'T2_HLH_F826', 'T2_HLH_F829', 'T2_HLH_F834', 'T2_HLH_F839', 'T2_HLH_F906', 'T2_HLH_F1066', 'T2_HLH_F1082', 'T2_HHL_F5', 'T2_HHL_F282', 'T2_HHL_F298', 'T2_HHL_F378', 'T2_HHL_F505', 'T2_HHL_F506', 'T2_HHL_F553', 'T2_HHL_F570', 'T2_HHL_F573', 'T2_HHL_F578', 'T2_HHL_F736', 'T2_HHL_F762', 'T2_HHL_F765', 'T2_HHL_F766', 'T2_HHL_F767', 'T2_HHL_F770', 'T2_HHL_F771', 'T2_HHL_F773', 'T2_HHL_F775', 'T2_HHL_F841', 'T2_HHL_F970', 'T2_HHL_F1034', 'T2_HHL_F1066', 'T2_HHL_F1081', 'T2_HHH_F5', 'T2_HHH_F23', 'T2_HHH_F41', 'T2_HHH_F43', 'T2_HHH_F44', 'T2_HHH_F74', 'T2_HHH_F202', 'T2_HHH_F298', 'T2_HHH_F330', 'T2_HHH_F426', 'T2_HHH_F506', 'T2_HHH_F509', 'T2_HHH_F510', 'T2_HHH_F511', 'T2_HHH_F514', 'T2_HHH_F515', 'T2_HHH_F517', 'T2_HHH_F519', 'T2_HHH_F570', 'T2_HHH_F736', 'T2_HHH_F826', 'T2_HHH_F874', 'T2_HHH_F906', 'T2_HHH_F1066', 'T2_HHH_F1081', 'FLAIR_ORI_F27', 'FLAIR_ORI_F28', 'FLAIR_ORI_F30', 'FLAIR_ORI_F33', 'FLAIR_ORI_F34', 'FLAIR_ORI_F35', 'FLAIR_ORI_F37', 'FLAIR_ORI_F38', 'FLAIR_ORI_F298', 'FLAIR_ORI_F314', 'FLAIR_ORI_F317', 'FLAIR_ORI_F322', 'FLAIR_ORI_F327', 'FLAIR_ORI_F538', 'FLAIR_ORI_F634', 'FLAIR_ORI_F794', 'FLAIR_ORI_F807', 'FLAIR_ORI_F826', 'FLAIR_ORI_F874', 'FLAIR_ORI_F941', 'FLAIR_ORI_F946', 'FLAIR_ORI_F1066', 'FLAIR_ORI_F1082', 'FLAIR_LLL_F28', 'FLAIR_LLL_F35', 'FLAIR_LLL_F106', 'FLAIR_LLL_F298', 'FLAIR_LLL_F442', 'FLAIR_LLL_F874', 'FLAIR_LLL_F941', 'FLAIR_LLL_F946', 'FLAIR_LLL_F954', 'FLAIR_LLL_F1066', 'FLAIR_LLH_F62', 'FLAIR_LLH_F170', 'FLAIR_LLH_F186', 'FLAIR_LLH_F189', 'FLAIR_LLH_F194', 'FLAIR_LLH_F199', 'FLAIR_LLH_F378', 'FLAIR_LLH_F490', 'FLAIR_LLH_F506', 'FLAIR_LLH_F538', 'FLAIR_LLH_F698', 'FLAIR_LLH_F714', 'FLAIR_LLH_F730', 'FLAIR_LLH_F826', 'FLAIR_LLH_F875', 'FLAIR_LLH_F886', 'FLAIR_LLH_F922', 'FLAIR_LLH_F970', 'FLAIR_LLH_F1034', 'FLAIR_LLH_F1066', 'FLAIR_LHL_F74', 'FLAIR_LHL_F90', 'FLAIR_LHL_F103', 'FLAIR_LHL_F107', 'FLAIR_LHL_F139', 'FLAIR_LHL_F202', 'FLAIR_LHL_F266', 'FLAIR_LHL_F298', 'FLAIR_LHL_F302', 'FLAIR_LHL_F346', 'FLAIR_LHL_F349', 'FLAIR_LHL_F354', 'FLAIR_LHL_F355', 'FLAIR_LHL_F357', 'FLAIR_LHL_F359', 'FLAIR_LHL_F362', 'FLAIR_LHL_F378', 'FLAIR_LHL_F394', 'FLAIR_LHL_F426', 'FLAIR_LHL_F458', 'FLAIR_LHL_F490', 'FLAIR_LHL_F506', 'FLAIR_LHL_F510', 'FLAIR_LHL_F511', 'FLAIR_LHL_F538', 'FLAIR_LHL_F570', 'FLAIR_LHL_F573', 'FLAIR_LHL_F578', 'FLAIR_LHL_F602', 'FLAIR_LHL_F736', 'FLAIR_LHL_F762', 'FLAIR_LHL_F765', 'FLAIR_LHL_F766', 'FLAIR_LHL_F767', 'FLAIR_LHL_F770', 'FLAIR_LHL_F771', 'FLAIR_LHL_F773', 'FLAIR_LHL_F775', 'FLAIR_LHL_F826', 'FLAIR_LHL_F839', 'FLAIR_LHL_F842', 'FLAIR_LHL_F845', 'FLAIR_LHL_F850', 'FLAIR_LHL_F858', 'FLAIR_LHL_F874', 'FLAIR_LHL_F875', 'FLAIR_LHL_F878', 'FLAIR_LHL_F879', 'FLAIR_LHL_F886', 'FLAIR_LHL_F887', 'FLAIR_LHL_F970', 'FLAIR_LHL_F1034', 'FLAIR_LHL_F1050', 'FLAIR_LHL_F1066', 'FLAIR_LHH_F62', 'FLAIR_LHH_F74', 'FLAIR_LHH_F394', 'FLAIR_LHH_F426', 'FLAIR_LHH_F442', 'FLAIR_LHH_F505', 'FLAIR_LHH_F506', 'FLAIR_LHH_F510', 'FLAIR_LHH_F511', 'FLAIR_LHH_F538', 'FLAIR_LHH_F570', 'FLAIR_LHH_F730', 'FLAIR_LHH_F826', 'FLAIR_LHH_F839', 'FLAIR_LHH_F842', 'FLAIR_LHH_F845', 'FLAIR_LHH_F850', 'FLAIR_LHH_F906', 'FLAIR_LHH_F922', 'FLAIR_LHH_F970', 'FLAIR_LHH_F1066', 'FLAIR_HLL_F26', 'FLAIR_HLL_F27', 'FLAIR_HLL_F30', 'FLAIR_HLL_F32', 'FLAIR_HLL_F33', 'FLAIR_HLL_F34', 'FLAIR_HLL_F37', 'FLAIR_HLL_F38', 'FLAIR_HLL_F39', 'FLAIR_HLL_F40', 'FLAIR_HLL_F47', 'FLAIR_HLL_F74', 'FLAIR_HLL_F202', 'FLAIR_HLL_F266', 'FLAIR_HLL_F298', 'FLAIR_HLL_F314', 'FLAIR_HLL_F330', 'FLAIR_HLL_F378', 'FLAIR_HLL_F394', 'FLAIR_HLL_F397', 'FLAIR_HLL_F402', 'FLAIR_HLL_F426', 'FLAIR_HLL_F458', 'FLAIR_HLL_F506', 'FLAIR_HLL_F602', 'FLAIR_HLL_F634', 'FLAIR_HLL_F714', 'FLAIR_HLL_F730', 'FLAIR_HLL_F736', 'FLAIR_HLL_F826', 'FLAIR_HLL_F842', 'FLAIR_HLL_F858', 'FLAIR_HLL_F874', 'FLAIR_HLL_F875', 'FLAIR_HLL_F886', 'FLAIR_HLL_F906', 'FLAIR_HLL_F909', 'FLAIR_HLL_F914', 'FLAIR_HLL_F970', 'FLAIR_HLL_F1034', 'FLAIR_HLL_F1050', 'FLAIR_HLL_F1066', 'FLAIR_HLL_F1082', 'FLAIR_HLH_F90', 'FLAIR_HLH_F93', 'FLAIR_HLH_F98', 'FLAIR_HLH_F103', 'FLAIR_HLH_F202', 'FLAIR_HLH_F298', 'FLAIR_HLH_F330', 'FLAIR_HLH_F378', 'FLAIR_HLH_F394', 'FLAIR_HLH_F397', 'FLAIR_HLH_F402', 'FLAIR_HLH_F426', 'FLAIR_HLH_F490', 'FLAIR_HLH_F506', 'FLAIR_HLH_F570', 'FLAIR_HLH_F762', 'FLAIR_HLH_F775', 'FLAIR_HLH_F826', 'FLAIR_HLH_F841', 'FLAIR_HLH_F842', 'FLAIR_HLH_F874', 'FLAIR_HLH_F906', 'FLAIR_HLH_F970', 'FLAIR_HLH_F1066', 'FLAIR_HLH_F1081', 'FLAIR_HHL_F7', 'FLAIR_HHL_F426', 'FLAIR_HHL_F506', 'FLAIR_HHL_F688', 'FLAIR_HHL_F730', 'FLAIR_HHL_F826', 'FLAIR_HHL_F839', 'FLAIR_HHL_F874', 'FLAIR_HHL_F906', 'FLAIR_HHL_F1066', 'FLAIR_HHL_F1081', 'FLAIR_HHH_F27', 'FLAIR_HHH_F37', 'FLAIR_HHH_F74', 'FLAIR_HHH_F202', 'FLAIR_HHH_F266', 'FLAIR_HHH_F282', 'FLAIR_HHH_F298', 'FLAIR_HHH_F330', 'FLAIR_HHH_F394', 'FLAIR_HHH_F426', 'FLAIR_HHH_F506', 'FLAIR_HHH_F538', 'FLAIR_HHH_F570', 'FLAIR_HHH_F573', 'FLAIR_HHH_F578', 'FLAIR_HHH_F602', 'FLAIR_HHH_F730', 'FLAIR_HHH_F794', 'FLAIR_HHH_F842', 'FLAIR_HHH_F874', 'FLAIR_HHH_F877', 'FLAIR_HHH_F882', 'FLAIR_HHH_F906', 'FLAIR_HHH_F970', 'FLAIR_HHH_F1034', 'FLAIR_HHH_F1050', 'FLAIR_HHH_F1066', 'FLAIR_HHH_F1081', 'age', 'gender'};
predictors = inputTable(:, predictorNames);
response = inputTable.IDH;
isCategoricalPredictor = [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true];

% Perform cross-validation
partitionedModel = crossval(trainedClassifier.ClassificationSVM, 'KFold', 5);

% Compute validation predictions
[validationPredictions, validationScores] = kfoldPredict(partitionedModel);

% Compute validation accuracy
validationAccuracy = 1 - kfoldLoss(partitionedModel, 'LossFun', 'ClassifError');
